package IdPAccountManager::Data::ServiceProvider;

use strict;
use warnings;

use base 'IdPAccountManager::DB::Object';

__PACKAGE__->meta->setup(
    table   => 'serviceproviders',

    columns => [
        id          => { type => 'bigserial', not_null => 1 },
        entityid    => { type => 'varchar', length => 200, not_null => 1 },
        displayname => { type => 'varchar', length => 500 },
        contacts    => { type => 'varchar', length => 2000 },
    ],

    primary_key_columns => [ 'id' ],

    unique_key => [ 'entityid' ],
);

sub new {
    my ($pkg, %args) = @_;

    my $self = $pkg->SUPER::new(%args);

    $self->{dev_sp_contact} = $args{dev_sp_contact};

    return $self;
}

## Print the content of a test account
sub print {
    my ($self, $fd) = @_;
    $fd = \*STDOUT unless $fd;

    printf $fd
      "ServiceProvider ID=%s; entityid=%s; displayname=%s; contacts=%s\n",
      $self->id(), $self->entityid(), $self->displayname(), $self->contacts();
}

## list contacts for this SP, including those listed in conf.dev_sp_contact
sub list_contacts_as_array {
    my ($self) = @_;

    my %contact_list;

    foreach my $contact_email (split /,/, $self->contacts()) {
        $contact_list{$contact_email}++;
    }

    foreach my $contact_email (split /,/, $self->{dev_sp_contact}) {
        $contact_list{$contact_email}++;
    }

    return keys %contact_list;
}

## Check if email address is a known contact (or conf.dev_sp_contact)
sub is_contact {
    my ($self, $email) = @_;

    foreach my $known_contact ($self->list_contacts_as_array()) {
        return 1 if (lc($email) eq lc($known_contact));
    }

    return 0;
}

1;

